--Script outputs a MiTracking file. Set output to CSV, and remove the (X rows affected) statements from the results.
--The script outputs extra rows with 1 and 2 digit naics codes, where we don't have anything more than that in the data. MiTracking will ignore these rows when they import the file, so it's safe to leave them in the output.

SELECT 
	Naics, 
	employees,
	CASE
		WHEN employees > 0 AND employees <= 10 THEN '02'
		WHEN employees > 10 AND employees < 250 THEN '03'
		WHEN employees >= 250 THEN '04'
		ELSE '05'
	END AS CompanySize
INTO #CompanyBreakdown_FTE
FROM (
	SELECT 
		(SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 as employees,
		ui_acct,
		LEFT(Naics, 3) AS Naics
	FROM Emp_All_Years
	WHERE MEEI IN (1, 3, 4, 5, 6)
	AND CNTY NOT IN (996, 998)
	GROUP BY ui_acct, LEFT(Naics, 3)
) emps

SELECT
	'26' as GeographicArea,
	'2014-2016' as Year,
	left(Naics, 3) as Naics,
	CASE
		WHEN [Injury Desc] IN('AMPUTATION') THEN '02'
		WHEN [Injury Desc] IN('CUT/LACERATION', 'ABRASION/SCRATCH', 'BITES-ANIMAL/HUMAN') THEN '03'
		WHEN [Injury Desc] IN('CRUSH/CONTUSION') THEN '04'
		WHEN [Injury Desc] IN('DISLOCATION', 'FRACTURE', 'HERNIA', 'INFLAMM JOINTS', 'INFLAM-JOINTS') THEN '05'
		WHEN [Injury Desc] IN('SPRAINS/STRAINS', 'NERVOUS SYSTEM', 'CNTRL NERV SYS', 'CARPAL TUNNEL', 'STRAINS/SPRAINS', 'NERVES') THEN '06'
		WHEN [Injury Desc] IN('BURN-HEAT', 'BURN-CHEMICAL', 'ELECTRIC SHOCK', 'BURN (HEAT)', 'BURN (CHEM)') THEN '11'
		WHEN [Injury Desc] IN('CONCUSSION') THEN '12'
		WHEN [Injury Desc] IN('SUFFOCATION', 'PARASITIC DISEASE', 'DYSENTERY', 'ANTHRAX', 'BRUCELLOSIS', 'CONJUNCTIVITIS', 'TETANUS', 'TUBERCULOSIS', 'INFECT DISEASE', 'DERMATITIS UNS', 'SKIN INFECTIONS', 'SKIN CONDITIONS', 'DERMATITIS ALLERG', 'SKIN COND NEC',
								'FREEZING', 'HEARING LOSS', 'HEATSTROKE', 'POISONING', 'TOXIC MATERIAL', 'BLOOD DISEASE', 'UPPER RESPIR-TOXIC', 'RESPIRATORY, TOXIC', 'HEPATITIS, TOXIC', 'GASTROINTESTINAL', 'TOXIC POISONING', 'PNEUMOCONIOSIS', 'ALUMINOSIS',
								'ANTHRACOSIS', 'ASBESTOSIS', 'BYSSINOSIS', 'SIDEROSIS', 'SILICOSIS', 'LUNG DISEASE', 'TB/PNEUMOCONIOSIS', 'RADIATION EFFECTS', 'SUNBURN', 'MICROWAVE', 'X-RAY', 'ISOTOPES', 'WELDERS'' FLASH', 'HEMORRHOIDS', 'HEPATITIS',
								'EQUILIBRIUM', 'CEREBROVASCULAR', 'EYE DISEASES', 'STRESS', 'TUMOR/UNSPECIFIED', 'CANCER', 'BENIGN TUMOR', 'RESP SYS UNS', 'UPPER RESP', 'PNEUMONIA/FLU', 'RHINITIS', 'INSANITY/IMBECILITY', 'PARALYSIS', 'PROSTHETIC DAMAGE',
								'OCCUP DISEASE', 'HEART ATTACK', 'DERMTITS ALLRG', 'WELDERS FLASH') THEN '13'
		ELSE '14'
	END AS InjuryType,
	CASE
		WHEN employees > 0 AND employees <= 10 THEN '02'
		WHEN employees > 10 AND employees < 250 THEN '03'
		WHEN employees >= 250 THEN '04'
		ELSE '05'
	END AS CompanySize,
	[Part of Body Desc],
	ui_acct
INTO #AllMatches
FROM Match_All m
LEFT JOIN (
	SELECT 
		(SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 as employees,
		qcew_seq
	FROM Emp_2014
	WHERE MEEI IN (1, 3, 4, 5, 6)
	AND CNTY NOT IN (996, 998)
	GROUP BY qcew_seq
	) as emp ON m.qcew_seq = emp.qcew_seq

SELECT GeographicArea, Year, results.Naics, InjuryType, results.CompanySize,
CASE
	WHEN SUM(Cases) < 6 AND SUM(Cases) > 0 THEN '' 
	WHEN Employees IS NULL THEN ''
	ELSE FORMAT(SUM(Cases)  * 100 / (Employees * CASE
							WHEN LEFT(results.NAICS, 3) = '000' THEN 0.963847252
							WHEN LEFT(results.NAICS, 3) = '111' THEN 1.04243927
							WHEN LEFT(results.NAICS, 3) = '112' THEN 1.070877394
							WHEN LEFT(results.NAICS, 3) = '113' THEN 1.144792687
							WHEN LEFT(results.NAICS, 3) = '114' THEN 0.941260745
							WHEN LEFT(results.NAICS, 3) = '115' THEN 0.964851826
							WHEN LEFT(results.NAICS, 3) = '211' THEN 1.047272727
							WHEN LEFT(results.NAICS, 3) = '212' THEN 1.154868624
							WHEN LEFT(results.NAICS, 3) = '213' THEN 1.254751462
							WHEN LEFT(results.NAICS, 3) = '221' THEN 1.104877154
							WHEN LEFT(results.NAICS, 3) = '236' THEN 1.061316872
							WHEN LEFT(results.NAICS, 3) = '237' THEN 1.061316872
							WHEN LEFT(results.NAICS, 3) = '238' THEN 1.061316872
							WHEN LEFT(results.NAICS, 3) = '311' THEN 1.024105067
							WHEN LEFT(results.NAICS, 3) = '312' THEN 1.031867933
							WHEN LEFT(results.NAICS, 3) = '313' THEN 1.02170418
							WHEN LEFT(results.NAICS, 3) = '314' THEN 1.028040973
							WHEN LEFT(results.NAICS, 3) = '315' THEN 0.991044012
							WHEN LEFT(results.NAICS, 3) = '316' THEN 1.072658941
							WHEN LEFT(results.NAICS, 3) = '321' THEN 1.287594206
							WHEN LEFT(results.NAICS, 3) = '322' THEN 1.092261905
							WHEN LEFT(results.NAICS, 3) = '323' THEN 1.032727597
							WHEN LEFT(results.NAICS, 3) = '324' THEN 1.128141003
							WHEN LEFT(results.NAICS, 3) = '325' THEN 1.091758582
							WHEN LEFT(results.NAICS, 3) = '326' THEN 1.078428102
							WHEN LEFT(results.NAICS, 3) = '327' THEN 1.092908415
							WHEN LEFT(results.NAICS, 3) = '331' THEN 1.12771026
							WHEN LEFT(results.NAICS, 3) = '332' THEN 1.093647465
							WHEN LEFT(results.NAICS, 3) = '333' THEN 1.108008795
							WHEN LEFT(results.NAICS, 3) = '334' THEN 1.085329919
							WHEN LEFT(results.NAICS, 3) = '335' THEN 1.097864087
							WHEN LEFT(results.NAICS, 3) = '336' THEN 1.113603452
							WHEN LEFT(results.NAICS, 3) = '337' THEN 1.040068177
							WHEN LEFT(results.NAICS, 3) = '339' THEN 1.049982517
							WHEN LEFT(results.NAICS, 3) = '423' THEN 1.053844288
							WHEN LEFT(results.NAICS, 3) = '424' THEN 1.045772933
							WHEN LEFT(results.NAICS, 3) = '425' THEN 1.007971792
							WHEN LEFT(results.NAICS, 3) = '441' THEN 1.064754067
							WHEN LEFT(results.NAICS, 3) = '442' THEN 0.909775393
							WHEN LEFT(results.NAICS, 3) = '443' THEN 0.929599368
							WHEN LEFT(results.NAICS, 3) = '444' THEN 0.887152157
							WHEN LEFT(results.NAICS, 3) = '445' THEN 0.83493677
							WHEN LEFT(results.NAICS, 3) = '446' THEN 0.888225248
							WHEN LEFT(results.NAICS, 3) = '447' THEN 0.856478683
							WHEN LEFT(results.NAICS, 3) = '448' THEN 0.713728312
							WHEN LEFT(results.NAICS, 3) = '451' THEN 0.77021514
							WHEN LEFT(results.NAICS, 3) = '452' THEN 0.820052743
							WHEN LEFT(results.NAICS, 3) = '453' THEN 0.801214842
							WHEN LEFT(results.NAICS, 3) = '454' THEN 0.973294084
							WHEN LEFT(results.NAICS, 3) = '481' THEN 1.046185221
							WHEN LEFT(results.NAICS, 3) = '482' THEN 1.168194263
							WHEN LEFT(results.NAICS, 3) = '483' THEN 1.273031395
							WHEN LEFT(results.NAICS, 3) = '484' THEN 1.219347084
							WHEN LEFT(results.NAICS, 3) = '485' THEN 0.939462298
							WHEN LEFT(results.NAICS, 3) = '486' THEN 1.135061392
							WHEN LEFT(results.NAICS, 3) = '487' THEN 1.00191296
							WHEN LEFT(results.NAICS, 3) = '488' THEN 1.034708405
							WHEN LEFT(results.NAICS, 3) = '491' THEN 1.023835061
							WHEN LEFT(results.NAICS, 3) = '492' THEN 0.971410341
							WHEN LEFT(results.NAICS, 3) = '493' THEN 1.015467968
							WHEN LEFT(results.NAICS, 3) = '511' THEN 0.930304522
							WHEN LEFT(results.NAICS, 3) = '512' THEN 0.76030595
							WHEN LEFT(results.NAICS, 3) = '515' THEN 1.088968878
							WHEN LEFT(results.NAICS, 3) = '517' THEN 1.067782324
							WHEN LEFT(results.NAICS, 3) = '518' THEN 1.056857171
							WHEN LEFT(results.NAICS, 3) = '519' THEN 0.846916518
							WHEN LEFT(results.NAICS, 3) = '521' THEN 1.020078327
							WHEN LEFT(results.NAICS, 3) = '522' THEN 1.050804961
							WHEN LEFT(results.NAICS, 3) = '523' THEN 1.020078327
							WHEN LEFT(results.NAICS, 3) = '524' THEN 1.013569901
							WHEN LEFT(results.NAICS, 3) = '525' THEN 1.020078327
							WHEN LEFT(results.NAICS, 3) = '531' THEN 0.97649256
							WHEN LEFT(results.NAICS, 3) = '532' THEN 0.914746905
							WHEN LEFT(results.NAICS, 3) = '533' THEN 0.971956606
							WHEN LEFT(results.NAICS, 3) = '541' THEN 1.02116383
							WHEN LEFT(results.NAICS, 3) = '551' THEN 1.069090909
							WHEN LEFT(results.NAICS, 3) = '561' THEN 0.946506346
							WHEN LEFT(results.NAICS, 3) = '562' THEN 1.133161839
							WHEN LEFT(results.NAICS, 3) = '611' THEN 0.871210983
							WHEN LEFT(results.NAICS, 3) = '621' THEN 0.902729287
							WHEN LEFT(results.NAICS, 3) = '622' THEN 0.965901209
							WHEN LEFT(results.NAICS, 3) = '623' THEN 0.902693619
							WHEN LEFT(results.NAICS, 3) = '624' THEN 0.826863852
							WHEN LEFT(results.NAICS, 3) = '711' THEN 0.858353425
							WHEN LEFT(results.NAICS, 3) = '712' THEN 0.789324483
							WHEN LEFT(results.NAICS, 3) = '713' THEN 0.807039406
							WHEN LEFT(results.NAICS, 3) = '721' THEN 0.891909883
							WHEN LEFT(results.NAICS, 3) = '722' THEN 0.756902498
							WHEN LEFT(results.NAICS, 3) = '811' THEN 1.023394303
							WHEN LEFT(results.NAICS, 3) = '812' THEN 0.816968256
							WHEN LEFT(results.NAICS, 3) = '813' THEN 0.852787091
							WHEN LEFT(results.NAICS, 3) = '814' THEN 0.711441088
							WHEN LEFT(results.NAICS, 3) = '921' THEN 1
							WHEN LEFT(results.NAICS, 3) = '922' THEN 1
							WHEN LEFT(results.NAICS, 3) = '923' THEN 1
							WHEN LEFT(results.NAICS, 3) = '924' THEN 1
							WHEN LEFT(results.NAICS, 3) = '925' THEN 1
							WHEN LEFT(results.NAICS, 3) = '926' THEN 1
							WHEN LEFT(results.NAICS, 3) = '927' THEN 1
							WHEN LEFT(results.NAICS, 3) = '928' THEN 1
							ELSE 1
						END), '0.000') 
END as Rate INTO #NaicsRates
FROM 
(
	SELECT '26' as GeographicArea, '2014-2016' as Year, Naics, '01' as InjuryType, count(*) as Cases, '01' as CompanySize
	FROM #AllMatches
	GROUP BY Naics

	UNION

	SELECT '26' as GeographicArea, '2014-2016' as Year, Naics, InjuryType, count(*) as Cases, '01' as CompanySize
	FROM #AllMatches
	GROUP BY Naics, InjuryType

	UNION

	SELECT '26' as GeographicArea, '2014-2016' as Year, '000' as Naics, InjuryType, count(*) as Cases, '01' as CompanySize
	FROM #AllMatches
	GROUP BY InjuryType

	UNION

	SELECT '26' as GeographicArea, '2014-2016' as Year, '000' as Naics, '01' as InjuryType, count(*) as Cases, '01' as CompanySize
	FROM #AllMatches
	
	UNION

	--Special handling for sprain injury locations
	SELECT '26' as GeographicArea, '2014-2016' as Year, '000' as Naics,
		CASE
			WHEN [Part of Body Desc] IN('BACK') THEN '07'
			WHEN [Part of Body Desc] IN('SHOULDER(S)') THEN '08'
			WHEN [Part of Body Desc] IN('KNEE') THEN '09'
			WHEN [Part of Body Desc] IN('FINGER', 'FOREARM', 'HAND/FINGER(S)', 'ELBOW', 'ARM(S), UNS', 'UPPER ARM', 'HAND(S)', 'WRIST', 'ARM, NEC', 'UPP EXT UNS', 'UPP EXT MULTIPLE', 'ARM MULTIPLE') THEN '10'
		END as InjuryType, count(*) as Cases, '01' as CompanySize
	FROM #AllMatches
	WHERE InjuryType = '06'
	AND [Part of Body Desc] IN('BACK', 'SHOULDER(S)', 'KNEE', 'FINGER', 'FOREARM', 'HAND/FINGER(S)', 'ELBOW', 'ARM(S), UNS', 'UPPER ARM', 'HAND(S)', 'WRIST', 'ARM, NEC', 'UPP EXT UNS', 'UPP EXT MULTIPLE', 'ARM MULTIPLE')
	GROUP BY
		CASE
			WHEN [Part of Body Desc] IN('BACK') THEN '07'
			WHEN [Part of Body Desc] IN('SHOULDER(S)') THEN '08'
			WHEN [Part of Body Desc] IN('KNEE') THEN '09'
			WHEN [Part of Body Desc] IN('FINGER', 'FOREARM', 'HAND/FINGER(S)', 'ELBOW', 'ARM(S), UNS', 'UPPER ARM', 'HAND(S)', 'WRIST', 'ARM, NEC', 'UPP EXT UNS', 'UPP EXT MULTIPLE', 'ARM MULTIPLE') THEN '10'
		END

	UNION 

	--Special handling for company size with industry
	SELECT GeographicArea, Year, Naics, InjuryType, Cases, CompanySize
	FROM (
		SELECT '26' as GeographicArea, '2014-2016' as Year, InjuryType, '000' as Naics, count(*) as Cases, 
		CASE
			WHEN employees > 0 AND employees <= 10 THEN '02'
			WHEN employees > 10 AND employees < 250 THEN '03'
			WHEN employees >= 250 THEN '04'
			ELSE '05'
		END AS CompanySize
		FROM #AllMatches m
		LEFT JOIN (
			SELECT 
				(SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 as employees,
				ui_acct
			FROM Emp_All_Years
			GROUP BY ui_acct
			) as emp ON m.ui_acct = emp.ui_acct
		GROUP BY InjuryType, 
		CASE
			WHEN employees > 0 AND employees <= 10 THEN '02'
			WHEN employees > 10 AND employees < 250 THEN '03'
			WHEN employees >= 250 THEN '04'
			ELSE '05'
		END

		UNION

		SELECT '26' as GeographicArea, '2014-2016' as Year, '01' as InjuryType, '000' as Naics, count(*) as Cases, 
		CASE
			WHEN employees > 0 AND employees <= 10 THEN '02'
			WHEN employees > 10 AND employees < 250 THEN '03'
			WHEN employees >= 250 THEN '04'
			ELSE '05'
		END AS CompanySize
		FROM Match_All m
		LEFT JOIN (
			SELECT 
				(SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 as employees,
				ui_acct
			FROM Emp_All_Years
			GROUP BY ui_acct
			) as emp ON m.ui_acct = emp.ui_acct
		GROUP BY 
		CASE
			WHEN employees > 0 AND employees <= 10 THEN '02'
			WHEN employees > 10 AND employees < 250 THEN '03'
			WHEN employees >= 250 THEN '04'
			ELSE '05'
		END
	) companySize

	UNION

	SELECT '26' as GeographicArea, '2014-2016' as Year, InjuryType, Naics, 0 as employees, CompanySize
	FROM Other_Filter_Naics

) as results
LEFT JOIN 
(
	SELECT Naics, SUM(employees) as employees, CompanySize
	FROM #CompanyBreakdown_FTE
	GROUP BY Naics, CompanySize

	UNION

	SELECT '000' as Naics, SUM(employees) as employees, CompanySize
	FROM #CompanyBreakdown_FTE
	GROUP BY CompanySize

	UNION

	SELECT Naics, SUM(employees) as employees, '01' as CompanySize
	FROM #CompanyBreakdown_FTE
	GROUP BY Naics

	UNION

	SELECT '000' as Naics, SUM(employees) as employees, '01' as CompanySize
	FROM #CompanyBreakdown_FTE
) AS denom ON results.naics = denom.naics AND results.CompanySize = denom.CompanySize
Where denom.CompanySize != '05'
AND denom.employees != 0 -- Throw out counties that have no employees, so they show up as an unknown rate
GROUP BY GeographicArea, Year, InjuryType, employees, results.CompanySize, results.Naics

UPDATE n
SET n.Rate = '' 
FROM #NaicsRates n
WHERE Naics IN (
	SELECT Naics FROM #NaicsRates 
	where Rate = ''
	group by Naics
	having count(*) = 1
	)
AND Rate = (
	SELECT min(Rate) FROM #NaicsRates nc
	WHERE n.Naics = nc.Naics
	AND Rate != ''
	)

UPDATE n
SET n.Rate = ''
FROM #NaicsRates n
WHERE Naics = 1
AND InjuryType IN (
	SELECT InjuryType FROM #NaicsRates
	WHERE Rate = ''
	AND Naics = 1
	group by InjuryType
	having count(*) = 1
	)
AND Rate = (
	SELECT min(Rate) FROM #NaicsRates nc
	where n.InjuryType = nc.InjuryType
	AND Naics = 1
	AND Rate != ''
	)

SELECT * FROM #NaicsRates
ORDER BY Naics, InjuryType;

DROP TABLE #AllMatches;
DROP TABLE #NaicsRates;
DROP TABLE #CompanyBreakdown_FTE;